@@ -1,10 +1,10 @@
 rndtaxa <- function(taxa,replace=FALSE,species=FALSE,plots=FALSE)
 {
     if (species) {
-        out <- apply(taxa,2,sample)
+        out <- apply(taxa,2,sample,replace=replace)
     }
     if (plots) {
-        out <- apply(taxa,1,sample)
+        out <- apply(taxa,1,sample,replace=replace)
     }
     if (!species & !plots) {
         tmp <- as.vector(as.matrix(taxa))
